@@ -58,6 +58,7 @@ export type GDPSInstallerState = {
   isLocalInstall: boolean;
   sshUsername: string;
   sshKeyfile: string;
+  dbuser: string;
   tg_cluster_mode: boolean;
 };
 
@@ -105,7 +106,11 @@ export type TmpOutputFormProps = {
 };
 
 export type SSHFormProps = {
-  update: (state: { sshUsername: string; sshKeyfile: string }) => void;
+  update: (state: {
+    sshUsername: string;
+    sshKeyfile: string;
+    dbuser: string;
+  }) => void;
 };
 
 export type VolumeMountFormProps = {
